==> huaweicloudsdkworkspace-3.1.87-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/create_tag_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateTagRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'desktop_id': 'str',
        'body': 'CreateTagReq'
    }

    attribute_map = {
        'desktop_id': 'desktop_id',
        'body': 'body'
    }

    def __init__(self, desktop_id=None, body=None):
        """CreateTagRequest

        The model defined in huaweicloud sdk

        :param desktop_id: 桌面id。
        :type desktop_id: str
        :param body: Body of the CreateTagRequest
        :type body: :class:`huaweicloudsdkworkspace.v2.CreateTagReq`
        """
        
        

        self._desktop_id = None
        self._body = None
        self.discriminator = None

        self.desktop_id = desktop_id
        if body is not None:
            self.body = body

    @property
    def desktop_id(self):
        """Gets the desktop_id of this CreateTagRequest.

        桌面id。

        :return: The desktop_id of this CreateTagRequest.
        :rtype: str
        """
        return self._desktop_id

    @desktop_id.setter
    def desktop_id(self, desktop_id):
        """Sets the desktop_id of this CreateTagRequest.

        桌面id。

        :param desktop_id: The desktop_id of this CreateTagRequest.
        :type desktop_id: str
        """
        self._desktop_id = desktop_id

    @property
    def body(self):
        """Gets the body of this CreateTagRequest.

        :return: The body of this CreateTagRequest.
        :rtype: :class:`huaweicloudsdkworkspace.v2.CreateTagReq`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this CreateTagRequest.

        :param body: The body of this CreateTagRequest.
        :type body: :class:`huaweicloudsdkworkspace.v2.CreateTagReq`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateTagRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkworkspace-3.1.155-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/create_tag_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateTagRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'desktop_id': 'str',
        'body': 'CreateTagReq'
    }

    attribute_map = {
        'desktop_id': 'desktop_id',
        'body': 'body'
    }

    def __init__(self, desktop_id=None, body=None):
        r"""CreateTagRequest

        The model defined in huaweicloud sdk

        :param desktop_id: 桌面id。
        :type desktop_id: str
        :param body: Body of the CreateTagRequest
        :type body: :class:`huaweicloudsdkworkspace.v2.CreateTagReq`
        """
        
        

        self._desktop_id = None
        self._body = None
        self.discriminator = None

        self.desktop_id = desktop_id
        if body is not None:
            self.body = body

    @property
    def desktop_id(self):
        r"""Gets the desktop_id of this CreateTagRequest.

        桌面id。

        :return: The desktop_id of this CreateTagRequest.
        :rtype: str
        """
        return self._desktop_id

    @desktop_id.setter
    def desktop_id(self, desktop_id):
        r"""Sets the desktop_id of this CreateTagRequest.

        桌面id。

        :param desktop_id: The desktop_id of this CreateTagRequest.
        :type desktop_id: str
        """
        self._desktop_id = desktop_id

    @property
    def body(self):
        r"""Gets the body of this CreateTagRequest.

        :return: The body of this CreateTagRequest.
        :rtype: :class:`huaweicloudsdkworkspace.v2.CreateTagReq`
        """
        return self._body

    @body.setter
    def body(self, body):
        r"""Sets the body of this CreateTagRequest.

        :param body: The body of this CreateTagRequest.
        :type body: :class:`huaweicloudsdkworkspace.v2.CreateTagReq`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateTagRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
